#! /bin/sh

# Environment vars needed: 
#	PGE_SOURCE
#	PGE_SERVERDEST
#	PGE_DBDEST
#	PGE_SERVERNAME
#	PGE_REGNUM

INSTALLED_FILES=""

config_echo () {
	/bin/echo "`/bin/date` `/bin/hostname` config-install.sh [$$]: $1" \
		> /dev/console;
}

config_echo "---------- Started."

#
# Make sure we're root. 
#

if [ `/usr/ucb/whoami` != "root" ]; then
	config_echo "Must run $0 as root."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Check to make sure there's not already a server or database installed.
#

if [ -f "$PGE_SERVERDEST/bin/PGEServer" ]; then
	config_echo "Won't overwrite existing $PGE_SERVERDEST/bin/PGEServer."
	config_echo "---------- Exiting."
	exit 1
fi

if [ \( -f "$PGE_DBDEST/PGE.store" \) -o \( -d "$PGE_DBDEST/PGE.store" \) ]; then
	config_echo "Won't overwrite existing $PGE_DBDEST/PGE.store."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Check the distribution.
#

if [ ! -f "$PGE_SOURCE/MindShare" ]; then
	config_echo "Can't find server binary $PGE_SOURCE/MindShare."
	config_echo "---------- Exiting."
	exit 1
fi	

if [ ! -f "$PGE_SOURCE/rc.pge" ]; then
	config_echo "Can't find server startup script $PGE_SOURCE/rc.pge."
	config_echo "---------- Exiting."
	exit 1
fi	

if [ ! -f "$PGE_SOURCE/pge_daily" ]; then
	config_echo "Can't find daily housekeeping file $PGE_SOURCE/pge_daily."
	config_echo "---------- Exiting."
	exit 1
fi	

#
# Make sure there's not a running server with that name.
#

if /bin/ps auxwwww | /bin/grep PGEServer | /bin/grep "$PGE_SERVERNAME" | /bin/grep -v grep; then
	config_echo "Won't kill PGEServer \"$PGE_SERVERNAME\"."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Create the destination directories. Make sure they can be written. 
#

if [ \( -z "$PGE_SERVERDEST/bin" -a ! -w "$PGE_SERVERDEST/bin" \) \
	-o \( -z "$PGE_SERVERDEST/etc" -a ! -w "$PGE_SERVERDEST/etc" \) ]; then
	config_echo "Can't install files in $PGE_SERVERDEST."
	config_echo "---------- Exiting."
	exit 1	
fi
/bin/mkdirs "$PGE_SERVERDEST/bin"
/bin/mkdirs "$PGE_SERVERDEST/etc"

if [ -z "$PGE_DBDEST" -a ! -w "$PGE_DBDEST" ]; then
	config_echo "Can't install PGE database in $PGE_DBDEST."
	config_echo "---------- Exiting."
	exit 1	
fi
/bin/mkdirs "$PGE_DBDEST"

#
# Copy the files. 
#

if /bin/cp "$PGE_SOURCE/MindShare" "$PGE_SERVERDEST/bin/PGEServer"; then
	INSTALLED_FILES="$INSTALLED_FILES $PGE_SERVERDEST/bin/PGEServer"
else
	config_echo "Can't install PGE server in $PGE_SERVERDEST."
	config_echo "---------- Exiting."
	exit 1
fi

if /bin/cp "$PGE_SOURCE/rc.pge" "$PGE_SERVERDEST/etc"; then
	INSTALLED_FILES="$INSTALLED_FILES $PGE_SERVERDEST/etc/rc.pge"
else
	config_echo "Can't install rc.pge in $PGE_SERVERDEST/etc."
	config_echo "---------- Exiting."
	exit 1	
fi

if /bin/cp "$PGE_SOURCE/pge_daily" "$PGE_SERVERDEST/etc"; then
	INSTALLED_FILES="$INSTALLED_FILES $PGE_SERVERDEST/etc/pge_daily"
else
	config_echo "Can't install pge_daily in $PGE_SERVERDEST/etc."
	config_echo "---------- Exiting."
	exit 1	
fi

#
# Modify and write pge_daily. 
#

/bin/sed "s%<<database-path>>%$PGE_DBDEST%;				\
	s%<<server-path>>%$PGE_SERVERDEST%;				\
	s%<<server-name>>%$PGE_SERVERNAME%;" "$PGE_SOURCE/pge_daily"	\
		> "$PGE_SERVERDEST"/etc/pge_daily

#
# Modify and write rc.pge. 
#

/bin/sed "s%<<database-path>>%$PGE_DBDEST%;				\
	s%<<server-path>>%$PGE_SERVERDEST/bin%;				\
	s%<<server-name>>%$PGE_SERVERNAME%;" "$PGE_SOURCE/rc.pge"	\
		> "$PGE_SERVERDEST"/etc/rc.pge

#
# Modify the /etc/rc.local.
#

if [ ! -f "/etc/rc.local" ]; then
	config_echo "Creating /etc/rc.local"
	/usr/bin/touch /etc/rc.local
else
	config_echo "Creating backup of /etc/rc.local in /etc/rc.local.backup."
	/bin/cp /etc/rc.local /etc/rc.local.backup
fi

if /bin/grep "rc.pge" /etc/rc.local; then
	config_echo "/etc/rc.local already starts rc.pge."
else
	echo "\n# Start PGE server. DO NOT MODIFY THE NEXT 3 LINES.\nif [ -f $PGE_SERVERDEST/etc/rc.pge ]; then\n	/bin/sh $PGE_SERVERDEST/etc/rc.pge\nfi\n" >> /etc/rc.local
fi

#
# Modify /etc/crontab.local.
# (creating it if necessary)
# (and making sure it doesn't already contain pge stuff)
#

if [ ! -f /etc/crontab.local ]; then
	config_echo "Creating /etc/crontab.local"
	/usr/bin/touch /etc/crontab.local
else
	config_echo "Creating backup of /etc/crontab.local in /etc/crontab.local.backup."
	/bin/cp /etc/crontab.local /etc/crontab.local.backup
fi

if /bin/grep "pge_daily" /etc/crontab.local; then
	config_echo "/etc/crontab.local already runs pge_daily."
else
	echo "# Run PGE housekeeping script. DO NOT MODIFY THE NEXT LINE.\n0 23 * * *              root    $PGE_SERVERDEST/etc/pge_daily">> /etc/crontab.local
fi

#
# Register the database
# (run -license, then shut down the server when it's done)
#

config_echo "Licensing server."
INSTALLED_FILES="$INSTALLED_FILES $PGE_DBDEST/PGE.store"
"$PGE_SERVERDEST/bin/PGEServer" -server "$PGE_SERVERNAME"Setup \
	-license "$PGE_REGNUM" -directory "$PGE_DBDEST" -create &
license_pid=$!

count=30
while [ \( ! -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
	sleep 10
	count=`expr $count - 1`
done

if [ ! -f "$PGE_DBDEST/lockfile" ]; then
	config_echo "Failed to license PGEServer. Removing installed files."
	/bin/rm -f "$INSTALLED_FILES"	
	config_echo "---------- Exiting."
	exit 1
fi

if [ "$count" -eq 0 ];then
	config_echo "Failed to start PGEServer for licensing. Removing installed files."
	/bin/rm -f "$INSTALLED_FILES"	
	config_echo "---------- Exiting."
	exit 1
fi

#
# Shutdown the license server.
#

config_echo "Shutting down the license server."

if "$PGE_SERVERDEST"/bin/PGEServer -server "$PGE_SERVERNAME"Setup -kill; then
	config_echo "Server shutdown can take up to 10 minutes. Please wait."
	count=60
	while [ \( -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
		sleep 10
		count=`expr $count - 1`
	done
fi

if [ -f "$PGE_DBDEST"/lockfile ]; then
	config_echo Failed to kill PGEServer "$PGE_SERVERNAME"Setup.
	config_echo "Database in $PGE_DBDEST is locked."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Run the new server and make sure it's up. 
#

config_echo "Starting new server."
/bin/sh "$PGE_SERVERDEST"/etc/rc.pge

count=30
while [ \( ! -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
	sleep 10
	count=`expr $count - 1`
done
if [ "$count" -eq 0 ];then
	config_echo "Failed to start PGEServer. Removing installed files."
	/bin/rm -f "$INSTALLED_FILES"	
	config_echo "---------- Exiting."
	exit 1
fi

config_echo "PGEServer installed successfully."
config_echo "---------- Exiting."

exit 0
