#! /bin/sh

# Environment vars needed: PGE_SERVERDEST, PGE_SERVERNAME, PGE_REGNUM

config_echo () {
	/bin/echo "`/bin/date` `/bin/hostname` config-reregister.sh [$$]: $1" \
		> /dev/console;
}

config_echo "---------- Started."

#
# Make sure we're root. 
#

if [ `/usr/ucb/whoami` != "root" ]; then
	config_echo "Must run $0 as root."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Check availability of PGEServer and rc.pge.
#

if [ ! -f "$PGE_SERVERDEST/bin/PGEServer" ]; then
	config_echo "Can't run $PGE_SERVERDEST/bin/PGEServer."
	config_echo "---------- Exiting."
	exit 1
fi

if [ ! -f "$PGE_SERVERDEST/etc/rc.pge" ]; then
	config_echo "Can't run $PGE_SERVERDEST/etc/rc.pge."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Shut down the running server if there is one. 
#

config_echo "Shutting down PGEServer."

if "$PGE_SERVERDEST/bin/PGEServer" -server "$PGE_SERVERNAME" -kill; then
	config_echo "Server shutdown can take up to 10 minutes. Please wait."
	count=60
	while [ \( -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
		sleep 10
		count=`expr $count - 1`
	done
fi

if [ -f "$PGE_DBDEST"/lockfile ]; then
	config_echo "Failed to kill PGEServer $PGE_SERVERNAME."
	config_echo "Database in $PGE_DBDEST is locked."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Run with -license. 
#

config_echo "Licensing PGEServer."

"$PGE_SERVERDEST/bin/PGEServer" -server "$PGE_SERVERNAME" \
	-license "$PGE_REGNUM" -directory "$PGE_DBDEST" &

count=30
while [ \( ! -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
	sleep 10
	count=`expr $count - 1`
done
if [ "$count" -eq 0 ];then
	config_echo "Failed to start PGEServer for licensing."
	config_echo "---------- Exiting."
	exit 1
fi

#
# When done, kill the server
#

config_echo "Restarting the newly-licensed server."
if "$PGE_SERVERDEST"/bin/PGEServer -server "$PGE_SERVERNAME" -kill; then
	config_echo "Server shutdown can take up to 10 minutes. Please wait."
	count=60
	while [ \( -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
		sleep 10
		count=`expr $count - 1`
	done
fi

if [ -f "$PGE_DBDEST"/lockfile ]; then
	config_echo "Failed to kill PGEServer $PGE_SERVERNAME."
	config_echo "Database in $PGE_DBDEST is locked."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Shell rc.pge and make sure it's running. 
#

config_echo "Starting new server."
. "$PGE_SERVERDEST"/etc/rc.pge

count=30
while [ \( ! -f "$PGE_DBDEST"/lockfile \) -a \( "$count" -gt 0 \) ]; do
	sleep 10
	count=`expr $count - 1`
done
if [ "$count" -eq 0 ];then
	config_echo "Failed to start PGEServer."
	config_echo "---------- Exiting."
	exit 1
fi

config_echo "PGEServer registered successfully."
config_echo "---------- Exiting."

exit 0
