#! /bin/sh

# Environment vars needed: PGE_SOURCE, PGE_SERVERDEST, PGE_DBDEST, PGE_SERVERNAME

config_echo () {
	/bin/echo "`/bin/date` `/bin/hostname` config-upgrade.sh [$$]: $1" \
		> /dev/console;
}

config_echo "---------- Started."

#
# Make sure we're root. 
#

if [ `/usr/ucb/whoami` != "root" ]; then
	config_echo "Must run $0 as root."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Check the distribution.
#

if [ ! -f "$PGE_SOURCE/MindShare" ]; then
	config_echo "Can't find server binary $PGE_SOURCE/MindShare."
	config_echo "---------- Exiting."
	exit 1
fi

if [ ! -f "$PGE_SOURCE/pge_daily" ]; then
	config_echo "Can't find daily housekeeping file $PWD/pge_daily."
	config_echo "---------- Exiting."
	exit 1
fi	

#
# Make sure it's already installed. If not, fail. 
#

if [ ! -f "$PGE_SERVERDEST/bin/PGEServer" ]; then
	config_echo "Can't find existing $PGE_SERVERDEST/bin/PGEServer."
	config_echo "---------- Exiting."
	exit 1
fi

if [ \( ! -f "$PGE_DBDEST/PGE.store" \) -a \( ! -d "$PGE_DBDEST/PGE.store" \) ]; then
	config_echo "Can't find existing $PGE_DBDEST/PGE.store."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Make sure we can write the files we want to change. 
#

if [ ! \( -w "$PGE_SERVERDEST/bin/PGEServer" -a -w "$PGE_SERVERDEST/etc/pge_daily" \) ]; then
	config_echo "Can't upgrade files in $PGE_SERVERDEST."
	config_echo "---------- Exiting."
	exit 1	
fi

#
# Shut down the running server if there is one. 
#
if "$PGE_SERVERDEST"/bin/PGEServer -server "$PGE_SERVERNAME" -kill; then
	config_echo "Server shutdown can take up to 10 minutes. Please wait."
	count=60
	while [ \( -f "$PGE_DBDEST/lockfile" \) -a \( "$count" -gt 0 \) ]; do
		sleep 10
		count=`expr $count - 1`
	done
fi

if [ -f "$PGE_DBDEST"/lockfile ]; then
	config_echo "Failed to kill PGEServer $PGE_SERVERNAME."
	config_echo "Database in $PGE_DBDEST is locked."
	config_echo "---------- Exiting."
	exit 1
fi

#
# Replace the server binary.
#

/bin/mkdirs "$PGE_SERVERDEST/bin"
if /bin/cp "$PGE_SOURCE/MindShare" "$PGE_SERVERDEST/bin/PGEServer"; then
	:
else
	config_echo "Can't upgrade PGE database in $PGE_SERVERDEST."
	config_echo "---------- Exiting."
	exit 1	
fi

#
# Modify and write pge_daily. 
#

/bin/sed "s%<<database-path>>%$PGE_DBDEST%;				\
	s%<<server-path>>%$PGE_SERVERDEST%;				\
	s%<<server-name>>%$PGE_SERVERNAME%;" "$PGE_SOURCE/pge_daily"	\
		> "$PGE_SERVERDEST"/etc/pge_daily

#
# Repair the old database.
#

config_echo "Repairing the old PGE database."

"$PGE_SERVERDEST"/bin/PGEServer -server "$PGE_SERVERNAME" \
	-directory "$PGE_DBDEST" -repair all

config_echo "PGEServer upgraded successfully."
config_echo "Restart the computer to start the server."
config_echo "---------- Exiting."

exit 0
